==> kimageannotator_0.6.0.orig.tar.gz: kImageAnnotator-0.6.0/translations/kImageAnnotator_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CS">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Rozvržení</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Přenést do popředí</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Přenést na pozadí</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Vybrat předmět</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Hlavní nastavení</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Nastavení obrázku</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Barva textu</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Faktor obfuskace</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Stín prvku</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Nastavení prvku</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zavřít ostatní</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zavřít vše</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Zavřít všechny vlevo</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Zavřít všechny vpravo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Výběr nástroje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikovat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Okraje a průhlednost výplně</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Okraje a výplně</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Okraje a bez výplně</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Bez okrajů a bez výplně</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Velikost písma</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučně</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzívou</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtrženo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekty obrázku</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Bez efektů</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Stupně šedi</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertovat barvy</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Omezeno</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikovat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Barva pozadí plátna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Otáčení obrázku</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° ve směru hodinových ručiček</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Libovolné</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Kladné hodnoty se otáčejí ve směru hodinových ručiček, záporné hodnoty proti směru hodinových ručiček.
Otáčení jinými násobky než 90°může způsobit ztrátu kvality.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontální</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikální</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Otočit</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Prohodit</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Roztažení obrázku</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Zachovat poměr stran</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished">Výška:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procenta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Nálepka</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Vyberte</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Číslo</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Obdélník zvýrazňovačem</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elipsa zvýrazňovačem</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dvojitá šipka</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Rozmazání</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Číselník</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Nálepka</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelizuj</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Textový ukazatel</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikuj</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished">Přiblížit (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished">Oddálit (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Resetovat přiblížení (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.6.1.orig.tar.gz: kImageAnnotator-0.6.1/translations/kImageAnnotator_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CS">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Rozvržení</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Přenést do popředí</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Přenést na pozadí</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Vybrat předmět</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopírovat</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Vložit</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Upravit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Smazat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Hlavní nastavení</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Nastavení obrázku</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Barva</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Barva textu</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Šířka</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Faktor obfuskace</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Stín prvku</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Nastavení prvku</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Zavřít ostatní</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Zavřít vše</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Zavřít všechny vlevo</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Zavřít všechny vpravo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Výběr nástroje</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Povoleno</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Zakázáno</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Otočit</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikovat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Vertikální</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Horizontální</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Aplikovat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Zrušit</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Okraje a průhlednost výplně</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Okraje a výplně</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Okraje a bez výplně</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Bez okrajů a bez výplně</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Velikost písma</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tučně</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kurzívou</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtrženo</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efekty obrázku</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Bez efektů</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Stupně šedi</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Okraje</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Invertovat barvy</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Omezeno</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>Š:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>V:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Aplikovat</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Barva:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Barva pozadí plátna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Otáčení obrázku</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° ve směru hodinových ručiček</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° proti směru hodinových ručiček</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Libovolné</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Kladné hodnoty se otáčejí ve směru hodinových ručiček, záporné hodnoty proti směru hodinových ručiček.
Otáčení jinými násobky než 90°může způsobit ztrátu kvality.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horizontální</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikální</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Otočit</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Prohodit</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Roztažení obrázku</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Zachovat poměr stran</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Šířka:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="unfinished">Výška:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Pixel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Procenta</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Nálepka</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Vyberte</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pero</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Číslo</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Obdélník zvýrazňovačem</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Elipsa zvýrazňovačem</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Zvýrazňovač</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Šipka</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Dvojitá šipka</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Rozmazání</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Obdélník</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elipsa</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Číselník</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Nálepka</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelizuj</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Textový ukazatel</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikuj</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation type="unfinished">Přiblížit (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation type="unfinished">Oddálit (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Resetovat přiblížení (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
